complete -c arch-repro-status -s m -l maintainer -d 'Sets the username of the maintainer' -r
complete -c arch-repro-status -s r -l rebuilderd -d 'Sets the address of the rebuilderd instance' -r
complete -c arch-repro-status -s b -l dbpath -d 'Sets the path to the pacman database' -r
complete -c arch-repro-status -l repos -d 'Sets the repositories to query' -r
complete -c arch-repro-status -s n -l pkgnames -d 'Sets the specific packages to query for' -r
complete -c arch-repro-status -s f -l filter -d 'Sets the filter for package status' -r -f -a "GOOD\t''
BAD\t''
UNKWN\t''"
complete -c arch-repro-status -s p -l pager -d 'Sets the pager for viewing files' -r
complete -c arch-repro-status -s c -l cache-dir -d 'Sets the cache directory for log files' -r -F
complete -c arch-repro-status -s q -l quiet -d 'Disables logging'
complete -c arch-repro-status -s v -l verbose -d 'Increases the logging verbosity'
complete -c arch-repro-status -s a -l all -d 'Checks all of the packages on the system'
complete -c arch-repro-status -s i -l inspect -d 'Views the build log or diffoscope of the interactively selected package'
complete -c arch-repro-status -s h -l help -d 'Print help'
complete -c arch-repro-status -s V -l version -d 'Print version'
